[−][src]Crate lfs_core
Use read_all to get information on all mounted volumes on a unix system.
// get all mount points let mut mounts = lfs_core::read_all().unwrap(); // only keep the one with a size mounts.retain(|m| m.size() > 0); // print them for mount in mounts { dbg!(mount); }
Structs
| DeviceId | Id of a device, as can be found in MetadataExt.dev(). |
| Mount | A mount point |
| Stats | inode & blocs information given by statvfs |
Enums
| Error | lfs error type |
Functions
| read_all | read all the mount points and load basic information on them |
Type Definitions
| MountId | An id of a mount |
| Result |